@@ -43,7 +43,7 @@ CScheduleView::CScheduleView(QWidget *parent, ScheduleViewPos viewType)
     : DFrame(parent)
     , m_viewPos(viewType)
     , m_touchGesture(this)
-    , m_timeFormat(CalendarManager::getInstance()->getCalendarDateDataManage()->getTimeFormat())
+    , m_timeFormat(CalendarManager::getInstance()->getTimeFormat())
 {
     initUI();
     initConnection();
@@ -124,9 +124,9 @@ void CScheduleView::setTime(QTime time)
     m_graphicsView->setTime(time);
 }
 
-void CScheduleView::setSelectSchedule(const ScheduleDataInfo &scheduleInfo)
+void CScheduleView::setSelectSchedule(const DSchedule::Ptr &scheduleInfo)
 {
-    if (scheduleInfo.getAllDay()) {
+    if (scheduleInfo->allDay()) {
         m_alldaylist->setSelectSearchSchedule(scheduleInfo);
     } else {
         m_graphicsView->setSelectSearchSchedule(scheduleInfo);
@@ -153,7 +153,7 @@ void CScheduleView::setCurrentDate(const QDateTime &currentDate)
  * @brief CScheduleView::setShowScheduleInfo        设置显示日程
  * @param scheduleInfo
  */
-void CScheduleView::setShowScheduleInfo(const QMap<QDate, QVector<ScheduleDataInfo> > &scheduleInfo)
+void CScheduleView::setShowScheduleInfo(const QMap<QDate, DSchedule::List> &scheduleInfo)
 {
     m_showSchedule = scheduleInfo;
     updateSchedule();
@@ -247,7 +247,7 @@ void CScheduleView::paintEvent(QPaintEvent *event)
                 painter.save();
                 painter.setFont(font);
                 painter.setPen(m_currenttimecolor);
-                QString str = QTime::currentTime().toString("AP " + m_timeFormat);
+                QString str = QTime::currentTime().toString(m_timeFormat);
                 painter.drawText(QRect((m_leftMargin - hourTextWidth) / 2 - 5,
                                        m_topMargin - 8 + m_vPos[m_vPos.count() - 1], hourTextWidth,
                                        hourTextHeight),
@@ -435,10 +435,6 @@ void CScheduleView::initConnection()
     connect(m_graphicsView, &CGraphicsView::signalGotoDayView, this,
             &CScheduleView::slotCurrentScheduleDate);
 
-    connect(m_alldaylist, &CAllDayEventWeekView::signalViewtransparentFrame, this,
-            &CScheduleView::signalViewtransparentFrame);
-    connect(m_graphicsView, &CGraphicsView::signalViewtransparentFrame, this,
-            &CScheduleView::signalViewtransparentFrame);
     //切换前后时间信号关联
     connect(m_graphicsView, &CAllDayEventWeekView::signalAngleDelta, this, &CScheduleView::signalAngleDelta);
     connect(m_alldaylist, &CAllDayEventWeekView::signalAngleDelta, this, &CScheduleView::signalAngleDelta);
@@ -484,14 +480,15 @@ void CScheduleView::slotCurrentScheduleDate(QDate date)
     emit signalsCurrentScheduleDate(date);
 }
 
-void CScheduleView::slotScheduleShow(const bool isShow, const ScheduleDataInfo &out)
+void CScheduleView::slotScheduleShow(const bool isShow, const DSchedule::Ptr &out)
 {
     if (isShow) {
         QVariant variant;
         CalendarGlobalEnv::getGlobalEnv()->getValueByKey(DDECalendar::CursorPointKey, variant);
         QPoint pos22 = variant.value<QPoint>();
+        //根据日程类型获取颜色
         CSchedulesColor gdColor = CScheduleDataManage::getScheduleDataManage()->getScheduleColorByType(
-                                      out.getType());
+            out->scheduleTypeID());
         QDesktopWidget *w = QApplication::desktop();
         m_ScheduleRemindWidget->setData(out, gdColor);
 
@@ -541,17 +538,19 @@ void CScheduleView::updateSchedule()
 {
     //获取一个月的日程信息
     m_graphicsView->clearSchedule();
-    QVector<ScheduleDataInfo> allInfo;
-    QVector<ScheduleDataInfo> nonAllInfo;
+    DSchedule::List allInfo;
+    DSchedule::List nonAllInfo;
 
-    QMap<QDate, QVector<ScheduleDataInfo> >::const_iterator _iterator = m_showSchedule.constBegin();
+    QMap<QDate, DSchedule::List>::const_iterator _iterator = m_showSchedule.constBegin();
     for (; _iterator != m_showSchedule.constEnd(); ++_iterator) {
         for (int i = 0; i < _iterator->size(); ++i) {
-            if (_iterator.value().at(i).getAllDay()) {
+            if (_iterator.value().at(i)->allDay()) {
+                //过滤
                 if (!allInfo.contains(_iterator.value().at(i))) {
                     allInfo.append(_iterator.value().at(i));
                 }
             } else {
+                //过滤
                 if (!nonAllInfo.contains(_iterator.value().at(i))) {
                     nonAllInfo.append(_iterator.value().at(i));
                 }
