@@ -22,6 +22,8 @@
 #include "dbuscalendar_adaptor.h"
 #include "widget/weekWidget/weekwindow.h"
 #include "widget/dayWidget/daywindow.h"
+#include "sidebarWidget/sidebarview.h"
+#include "colorWidget/colorpickerWidget.h"
 #include "scheduledatamanage.h"
 #include "myscheduleview.h"
 #include "configsettings.h"
@@ -33,6 +35,12 @@
 #include "ctitlewidget.h"
 #include "tabletconfig.h"
 #include "calendarglobalenv.h"
+#include "settingWidget/userloginwidget.h"
+#include "settingWidget/settingwidgets.h"
+
+#include "scheduletypeeditdlg.h"
+#include "accountmanager.h"
+#include "units.h"
 
 #include <DHiDPIHelper>
 #include <DPalette>
@@ -40,6 +48,12 @@
 #include <DWidgetUtil>
 #include <DTitlebar>
 #include <DApplicationHelper>
+#include <DSettings>
+#include <DSettingsGroup>
+#include <DSettingsOption>
+#include <DSettingsWidgetFactory>
+#include <DBackgroundGroup>
+#include <DMessageManager>
 
 #include <QDesktopWidget>
 #include <QJsonDocument>
@@ -51,12 +65,27 @@
 #include <QWidget>
 #include <QMenuBar>
 #include <QMouseEvent>
+#include <QColorDialog>
+#include <QApplication>
+#include <QWidgetAction>
+
+#include <stdlib.h>
+#include <functional>
 
 DGUI_USE_NAMESPACE
 DWIDGET_USE_NAMESPACE
 
-static const int CalendarMWidth = 860;
+static const int CalendarMWidth = 646;
 static const int CalendarMHeight = 634;
+const int CalendarSwitchWidth = 647; //当宽度小于这个尺寸时，标题栏需要切换显示逻辑
+const int CalendarViewSwitchWidth = 804; //当宽度小于这个尺寸时，视图部分需要切换显示逻辑
+
+const int Calendar_Default_Width = 860; //默认宽度
+const int Calendar_Default_Height = 634; //默认高度
+
+//静态的翻译不会真的翻译，但是会更新ts文件
+//像static QString a = QObject::tr("hello"), a实际等于hello，但是ts会有hello这个词条
+//调用DSetingDialog时会用到上述场景
 
 Calendarmainwindow::Calendarmainwindow(int index, QWidget *w)
     : DMainWindow(w)
@@ -65,6 +94,7 @@ Calendarmainwindow::Calendarmainwindow(int index, QWidget *w)
     setContentsMargins(QMargins(0, 0, 0, 0));
     initUI();
     initConnection();
+    initData();
     setMinimumSize(CalendarMWidth, CalendarMHeight);
     setWindowTitle(tr("Calendar"));
     new CalendarAdaptor(this);
@@ -106,14 +136,19 @@ Calendarmainwindow::Calendarmainwindow(int index, QWidget *w)
         int width = CConfigSettings::getInstance()->value("base.windowWidth").toInt();
         int height = CConfigSettings::getInstance()->value("base.windowHeight").toInt();
         QRect rect(0, 0, width, height);
-        rect.moveCenter(desktopwidget->geometry().center());
         this->setGeometry(rect);
     } else {
-        Dtk::Widget::moveToCenter(this);
+        //如果没有相关配置则设置为默认尺寸
+        QRect rect(0, 0, Calendar_Default_Width, Calendar_Default_Height);
+        this->setGeometry(rect);
     }
+    //在屏幕中央显示
+    Dtk::Widget::moveToCenter(this);
 
     //注册光标位置
     CalendarGlobalEnv::getGlobalEnv()->registerKey(DDECalendar::CursorPointKey, QPoint());
+    //保存主窗口指针
+    CalendarGlobalEnv::getGlobalEnv()->registerKey("MainWindow", QVariant::fromValue(static_cast<void *>(this)));
 }
 
 Calendarmainwindow::~Calendarmainwindow()
@@ -195,8 +230,7 @@ void Calendarmainwindow::viewWindow(int type, const bool showAnimation)
     case DDECalendar::CalendarYearWindow: {
         //更新界面显示
         m_yearwindow->updateData();
-    }
-    break;
+    } break;
     case DDECalendar::CalendarMonthWindow: {
     } break;
     case DDECalendar::CalendarWeekWindow: {
@@ -204,8 +238,7 @@ void Calendarmainwindow::viewWindow(int type, const bool showAnimation)
     case DDECalendar::CalendarDayWindow: {
         m_DayWindow->setTime();
         m_searchflag = true;
-    }
-    break;
+    } break;
     }
     m_priindex = type == 0 ? m_priindex : type;
     //为了与老版本配置兼容
@@ -228,12 +261,10 @@ void Calendarmainwindow::updateHeight()
     } break;
     case DDECalendar::CalendarWeekWindow: {
         m_weekWindow->updateHeight();
-    }
-    break;
+    } break;
     case DDECalendar::CalendarDayWindow: {
         m_DayWindow->updateHeight();
-    }
-    break;
+    } break;
     }
 }
 
@@ -285,8 +316,8 @@ void Calendarmainwindow::slotOpenSchedule(QString job)
 {
     if (job.isEmpty())
         return;
-    ScheduleDataInfo out;
-    out = ScheduleDataInfo::JsonStrToSchedule(job);
+    DSchedule::Ptr out;
+    DSchedule::fromJsonString(out, job);
 
     //设置被选中
     m_buttonBox->button(DDECalendar::CalendarDayWindow)->setChecked(true);
@@ -295,17 +326,22 @@ void Calendarmainwindow::slotOpenSchedule(QString job)
     //切换到日视图
     m_stackWidget->setCurrentIndex(DDECalendar::CalendarDayWindow);
     //设置选择时间
-    m_DayWindow->setSelectDate(out.getBeginDateTime().date());
+    m_DayWindow->setSelectDate(out->dtStart().date());
     //更新界面显示
     m_DayWindow->updateData();
     //设置非全天时间定位位置
-    m_DayWindow->setTime(out.getBeginDateTime().time());
+    m_DayWindow->setTime(out->dtStart().time());
     //弹出编辑对话框
-    CMyScheduleView dlg(out, this);
-    dlg.exec();
+    if(m_dlg == Q_NULLPTR) {
+        m_dlg = new CMyScheduleView(out,this);
+    } else {
+        m_dlg->setSchedules(out);
+        m_dlg->updateFormat();
+    }
+    if(m_dlg->isHidden())
+        m_dlg->exec();
     slotWUpdateSchedule();
 }
-
 void Calendarmainwindow::initUI()
 {
     //设置主窗口辅助技术显示名称和描述
@@ -319,22 +355,41 @@ void Calendarmainwindow::initUI()
     CDynamicIcon::getInstance()->setTitlebar(this->titlebar());
     CDynamicIcon::getInstance()->setIcon();
 
-    CTitleWidget *titleWidget = new CTitleWidget(this);
-    titleWidget->setFocusPolicy(Qt::TabFocus);
-    this->titlebar()->setCustomWidget(titleWidget);
-    setTabOrder(this->titlebar(), titleWidget);
+    m_titleWidget = new CTitleWidget(this);
+    m_titleWidget->setFocusPolicy(Qt::TabFocus);
+    this->titlebar()->setCustomWidget(m_titleWidget);
+    setTabOrder(this->titlebar(), m_titleWidget);
     //设置状态栏焦点代理为标题窗口
-    this->titlebar()->setFocusProxy(titleWidget);
+    this->titlebar()->setFocusProxy(m_titleWidget);
+    //this->titlebar()->setFocusProxy(titleWidget);
+
+    this->titlebar()->setQuitMenuVisible(true);//先设置后，才可以获取menu内容。因为setQuitMenuVisible接口中进行了action的添加操作
+    QMenu *menuTitleBar = this->titlebar()->menu();
+
+    QAction *pSetting = new QAction(tr("Manage"), menuTitleBar);
+    //menuTitleBar->addAction(pSetting);
+    menuTitleBar->insertSeparator(menuTitleBar->actions()[0]);
+    menuTitleBar->insertAction(menuTitleBar->actions()[0], pSetting);
+
+    connect(pSetting, &QAction::triggered, this, &Calendarmainwindow::slotOpenSettingDialog);
+
     //接收设置按键焦点
-    connect(titleWidget, &CTitleWidget::signalSetButtonFocus, [ = ] {
+    connect(m_titleWidget, &CTitleWidget::signalSetButtonFocus, [=] {
         m_setButtonFocus = true;
     });
-    connect(titleWidget, &CTitleWidget::signalSearchFocusSwitch, this,
+    connect(m_titleWidget, &CTitleWidget::signalSearchFocusSwitch, this,
             &Calendarmainwindow::slotSearchFocusSwitch);
 
-    m_searchEdit = titleWidget->searchEdit();
-    m_buttonBox = titleWidget->buttonBox();
-    m_newScheduleBtn = titleWidget->newScheduleBtn();
+    m_searchEdit = m_titleWidget->searchEdit();
+    m_buttonBox = m_titleWidget->buttonBox();
+    m_newScheduleBtn = m_titleWidget->newScheduleBtn();
+
+    QHBoxLayout *tMainLayout = new QHBoxLayout;
+    tMainLayout->setContentsMargins(10, 10, 10, 10);
+    tMainLayout->setSpacing(10);
+
+    m_sidebarView = new SidebarView(this);
+    tMainLayout->addWidget(m_sidebarView, 1);
 
     m_stackWidget = new AnimationStackedWidget();
     m_stackWidget->setObjectName("StackedWidget");
@@ -343,11 +398,9 @@ void Calendarmainwindow::initUI()
     m_stackWidget->setContentsMargins(0, 0, 0, 0);
     m_stackWidget->setDuration(250);
     createview();
-    QHBoxLayout *tMainLayout = new QHBoxLayout;
-    tMainLayout->setMargin(0);
-    tMainLayout->setSpacing(0);
-    tMainLayout->setContentsMargins(0, 0, 0, 0);
-    tMainLayout->addWidget(m_stackWidget);
+
+    tMainLayout->addWidget(m_stackWidget, 4);
+
     m_contentBackground = new DFrame;
     m_contentBackground->setAccessibleName("ScheduleSearchWidgetBackgroundFrame");
     m_contentBackground->setObjectName("ScheduleSearchWidgetBackgroundFrame");
@@ -365,12 +418,12 @@ void Calendarmainwindow::initUI()
     QVBoxLayout *ssLayout = new QVBoxLayout;
     ssLayout->setMargin(0);
     ssLayout->setSpacing(0);
-    ssLayout->setContentsMargins(0, 10, 0, 10);
-    ssLayout->addWidget(m_scheduleSearchView);
+    ssLayout->addWidget(m_scheduleSearchView, 1);
     m_contentBackground->setLayout(ssLayout);
-    tMainLayout->addWidget(m_contentBackground);
     m_contentBackground->setVisible(false);
 
+    tMainLayout->addWidget(m_contentBackground);
+
     DWidget *maincentralWidget = new DWidget(this);
     maincentralWidget->setAccessibleName("mainCentralWidget");
 
@@ -405,19 +458,9 @@ void Calendarmainwindow::initConnection()
             &Calendarmainwindow::slotSearchSelectSchedule);
     connect(m_scheduleSearchView, &CScheduleSearchView::signalScheduleHide, this,
             &Calendarmainwindow::setScheduleHide);
-    //界面弹出对话框设置背景阴影
-    connect(m_scheduleSearchView, &CScheduleSearchView::signalViewtransparentFrame, this,
-            &Calendarmainwindow::slotViewtransparentFrame);
+    connect(m_sidebarView,&SidebarView::signalScheduleHide,this,&Calendarmainwindow::setScheduleHide);
     connect(m_scheduleSearchView, &CScheduleSearchView::signalSelectCurrentItem, this,
             &Calendarmainwindow::slotSetSearchFocus);
-    connect(m_yearwindow, &CYearWindow::signalViewtransparentFrame, this,
-            &Calendarmainwindow::slotViewtransparentFrame);
-    connect(m_monthWindow, &CMonthWindow::signalViewtransparentFrame, this,
-            &Calendarmainwindow::slotViewtransparentFrame);
-    connect(m_weekWindow, &CWeekWindow::signalViewtransparentFrame, this,
-            &Calendarmainwindow::slotViewtransparentFrame);
-    connect(m_DayWindow, &CDayWindow::signalViewtransparentFrame, this,
-            &Calendarmainwindow::slotViewtransparentFrame);
     //更新当前时间
     connect(m_currentDateUpdateTimer, &QTimer::timeout, this,
             &Calendarmainwindow::slotCurrentDateUpdate);
@@ -427,6 +470,18 @@ void Calendarmainwindow::initConnection()
     connect(m_weekWindow, &CWeekWindow::signalSwitchView, this, &Calendarmainwindow::slotSwitchView);
     //按钮关联新建日程
     connect(m_newScheduleBtn, &DToolButton::clicked, this, &Calendarmainwindow::slotNewSchedule);
+
+    connect(qApp, &QGuiApplication::applicationStateChanged, this, &Calendarmainwindow::slotapplicationStateChanged);
+    connect(m_titleWidget, &CTitleWidget::signalSidebarStatusChange, this, &Calendarmainwindow::slotSidebarStatusChange);
+    //signalAccountUpdate
+    connect(gAccountManager, &AccountManager::signalSyncNum, this, &Calendarmainwindow::slotShowSyncToast);
+    connect(gAccountManager, &AccountManager::signalAccountUpdate, this, &Calendarmainwindow::slotAccountUpdate);
+}
+
+void Calendarmainwindow::initData()
+{
+    //根据配置设置侧边栏状态
+    m_titleWidget->setSidebarStatus(gSetting->getUserSidebarStatus());
 }
 
 /**
@@ -466,6 +521,39 @@ void Calendarmainwindow::createview()
     }
 }
 
+void Calendarmainwindow::resizeView()
+{
+    m_transparentFrame->resize(width(), height() - 50);
+
+    if (width() < CalendarSwitchWidth) {
+        m_titleWidget->setShowState(CTitleWidget::Title_State_Mini);
+    } else {
+        m_titleWidget->setShowState(CTitleWidget::Title_State_Normal);
+    }
+
+    int sidWidth = 0;
+    if (!m_sidebarView->isHidden()) {
+        sidWidth = m_sidebarView->width();
+    }
+
+    if (width() < CalendarViewSwitchWidth + sidWidth) {
+        m_isNormalStateShow = false;
+        m_stackWidget->setVisible(!m_contentBackground->isVisible());
+        // 如果是隐藏的状态，不需要多减去sidewidth
+        sidWidth = sidWidth == 0 ? 0 : sidWidth + 10;
+        m_scheduleSearchViewMaxWidth = this->width() - sidWidth;
+    } else {
+        m_scheduleSearchViewMaxWidth = qRound(0.2325 * (width()) + 0.5);
+        m_isNormalStateShow = true;
+        m_stackWidget->setVisible(true);
+        m_contentBackground->setVisible(m_opensearchflag);
+    }
+    // 额外减去20 是因为ui走查控件之间的space=10，两个间隔
+    m_scheduleSearchView->setMaxWidth(m_scheduleSearchViewMaxWidth - 20);
+    setSearchWidth(m_scheduleSearchViewMaxWidth - 20);
+    setScheduleHide();
+}
+
 /**
  * @brief Calendarmainwindow::setScheduleHide       隐藏提示框
  */
@@ -479,12 +567,20 @@ void Calendarmainwindow::setScheduleHide()
 
 void Calendarmainwindow::resizeEvent(QResizeEvent *event)
 {
-    m_transparentFrame->resize(width(), height() - 50);
-    m_scheduleSearchViewMaxWidth = qRound(0.2325 * width() + 0.5);
-    m_scheduleSearchView->setMaxWidth(m_scheduleSearchViewMaxWidth);
-    setSearchWidth(m_scheduleSearchViewMaxWidth);
-    setScheduleHide();
     DMainWindow::resizeEvent(event);
+
+    static int preWidth = 0;    //上一次界面宽度
+    //根据界面大小改变趋势设置侧边栏可显示状态
+    if ((preWidth >= 826 || preWidth == 0) && width() < 826) {
+        m_titleWidget->setSidebarCanDisplay(false);
+    } else if ((preWidth <= 826) && width() > 826) {
+        m_titleWidget->setSidebarCanDisplay(true);
+    }
+
+    preWidth = width();
+
+    resizeView();
+
     //保存窗口大小
     CConfigSettings::getInstance()->setOption("base.windowWidth", event->size().width());
     CConfigSettings::getInstance()->setOption("base.windowHeight", event->size().height());
@@ -496,7 +592,6 @@ void Calendarmainwindow::resizeEvent(QResizeEvent *event)
  */
 void Calendarmainwindow::slotstackWClicked(QAbstractButton *bt)
 {
-    m_buttonBox->setEnabled(false);
     setScheduleHide();
     int index = m_buttonBox->id(bt);
     viewWindow(index, true);
@@ -515,6 +610,13 @@ void Calendarmainwindow::slotSreturnPressed()
 {
     if (!m_opensearchflag && !m_searchEdit->text().isEmpty()) {
         m_opensearchflag = true;
+    }
+    //如果为搜索状态
+    if (m_opensearchflag) {
+        //根据显示显示状态，是否显示左侧视图窗口
+        if (!m_isNormalStateShow) {
+            m_stackWidget->setVisible(false);
+        }
         m_contentBackground->setVisible(true);
     }
     m_scheduleSearchView->slotsetSearch(m_searchEdit->text());
@@ -535,6 +637,7 @@ void Calendarmainwindow::slotStextChanged()
         m_weekWindow->setSearchWFlag(false);
         m_DayWindow->setSearchWFlag(false);
         m_contentBackground->setVisible(false);
+        m_stackWidget->setVisible(true);
         m_opensearchflag = false;
     }
     updateHeight();
@@ -560,17 +663,29 @@ void Calendarmainwindow::slotSearchEdit()
  * @brief Calendarmainwindow::slotSearchSelectSchedule  单击搜索日程动画设置
  * @param scheduleInfo
  */
-void Calendarmainwindow::slotSearchSelectSchedule(const ScheduleDataInfo &scheduleInfo)
+void Calendarmainwindow::slotSearchSelectSchedule(const DSchedule::Ptr &scheduleInfo)
 {
+    //如果小尺寸显示模式，在显示搜索窗口的时候，左侧视图会被隐藏
+    //如果点击一个搜索结果则隐藏搜索窗口，展示左侧视图
+    if (!m_isNormalStateShow) {
+        //        CalendarGlobalEnv::getGlobalEnv()->registerKey("SearchItemEvent", "Keyboard");
+
+        QVariant variant;
+        CalendarGlobalEnv::getGlobalEnv()->getValueByKey("SearchItemEvent", variant);
+        QString searchItemEvent = variant.toString();
+        //如果为鼠标点击操作
+        if (searchItemEvent == "MousePress") {
+            m_stackWidget->setVisible(true);
+            m_contentBackground->setVisible(false);
+        }
+    }
     //获取当前视图编号
-    CScheduleBaseWidget *_showWidget = dynamic_cast<CScheduleBaseWidget *>
-                                       (m_stackWidget->currentWidget());
+    CScheduleBaseWidget *_showWidget = dynamic_cast<CScheduleBaseWidget *>(m_stackWidget->currentWidget());
     if (_showWidget) {
         //如果日程开始时间年份与选择时间年份不一样则切换年份显示
-        bool changeYear = _showWidget->getSelectDate().year() !=
-                          scheduleInfo.getBeginDateTime().date().year();
+        bool changeYear = _showWidget->getSelectDate().year() != scheduleInfo->dtStart().date().year();
         //设置选择时间
-        if (_showWidget->setSelectDate(scheduleInfo.getBeginDateTime().date(), changeYear)) {
+        if (_showWidget->setSelectDate(scheduleInfo->dtStart().date(), changeYear)) {
             //更新显示数据
             _showWidget->updateData();
             //设置年份信息显示
@@ -593,16 +708,12 @@ void Calendarmainwindow::slotSearchSelectSchedule(const ScheduleDataInfo &schedu
  */
 void Calendarmainwindow::slotViewtransparentFrame(const bool isShow)
 {
-    static int showFrameCount = 0;
     if (isShow) {
         m_transparentFrame->resize(width(), height() - 50);
         m_transparentFrame->move(0, 50);
         m_transparentFrame->show();
-        ++showFrameCount;
     } else {
-        if (showFrameCount == 1)
-            m_transparentFrame->hide();
-        --showFrameCount;
+        m_transparentFrame->hide();
     }
 }
 
@@ -611,7 +722,6 @@ void Calendarmainwindow::slotViewtransparentFrame(const bool isShow)
  */
 void Calendarmainwindow::slotSetButtonBox()
 {
-    m_buttonBox->setEnabled(true);
     //如果为键盘操作则切换后设置焦点
     if (m_setButtonFocus) {
         //获取焦点
@@ -662,9 +772,7 @@ void Calendarmainwindow::slotNewSchedule()
     CScheduleDlg _scheduleDig(1, this, false);
     //设置开始时间
     _scheduleDig.setDate(_beginTime);
-    slotViewtransparentFrame(true);
     _scheduleDig.exec();
-    slotViewtransparentFrame(false);
 }
 
 void Calendarmainwindow::slotDeleteitem()
@@ -705,6 +813,18 @@ void Calendarmainwindow::slotSearchFocusSwitch()
     }
 }
 
+void Calendarmainwindow::slotSidebarStatusChange(bool status)
+{
+    //设置帐户侧边栏显示状态
+    m_sidebarView->setVisible(status);
+    //展开侧边栏后最小宽度为826
+    if (status && width() < 826) {
+        resize(826, height());
+    } else {
+        resizeView(); //刷新界面
+    }
+}
+
 void Calendarmainwindow::mouseMoveEvent(QMouseEvent *event)
 {
     //如果为平板模式则不可移动
@@ -726,8 +846,9 @@ void Calendarmainwindow::changeEvent(QEvent *event)
 
 void Calendarmainwindow::mousePressEvent(QMouseEvent *event)
 {
-    Q_UNUSED(event);
     setScheduleHide();
+    if (event->button() & Qt::LeftButton)
+        m_startPos = event->pos();
 }
 
 bool Calendarmainwindow::event(QEvent *event)
@@ -736,5 +857,81 @@ bool Calendarmainwindow::event(QEvent *event)
     if (event->type() == QEvent::Move) {
         setScheduleHide();
     }
+
+    //如果为活动窗口则显示视图阴影
+    if (event->type() == QEvent::WindowActivate) {
+        slotViewtransparentFrame(false);
+    }
+    //如果不为活动窗口则隐藏视图阴影
+    if (event->type() == QEvent::WindowDeactivate) {
+        slotViewtransparentFrame(true);
+    }
     return DMainWindow::event(event);
 }
+
+void Calendarmainwindow::slotapplicationStateChanged(Qt::ApplicationState state)
+{
+    static QDateTime currentDateTime = QDateTime::currentDateTime();
+    //TODO:目前没有找到窗口显示不是激活状态的原因（会先激活然后为非激活状态）。
+    //当间隔时间少于10毫秒且状态为非激活时，将窗口设置显示在最顶端并设置激活状态
+    if (state == Qt::ApplicationInactive) {
+        //获取当前时间
+        QDateTime currentTime = QDateTime::currentDateTime();
+        //考虑到会修改系统时间的情况，时间差在0～30毫秒内才会设置
+        if (currentDateTime.msecsTo(currentTime) < 30 && currentDateTime.msecsTo(currentTime) >= 0) {
+            activateWindow();
+            raise();
+        }
+        //断开信号连接
+        disconnect(qApp, &QGuiApplication::applicationStateChanged, this, &Calendarmainwindow::slotapplicationStateChanged);
+    }
+}
+
+void Calendarmainwindow::slotOpenSettingDialog()
+{
+    m_dsdSetting = new CSettingDialog(this);
+    //内容定位到顶端
+    m_dsdSetting->exec();
+    //使用完后释放
+    delete m_dsdSetting;
+    m_dsdSetting = nullptr;
+    gCalendarManager->updateData();
+}
+
+void Calendarmainwindow::slotShowSyncToast(int syncNum)
+{
+    //-1:正在刷新 0:正常 1:网络异常 2:服务器异常 3：存储已经满
+    static int preSyncNum = -2;
+    if (preSyncNum != syncNum && syncNum == -1) {
+        preSyncNum = -1;
+        //同步中
+        DMessageManager::instance()->sendMessage(this->window(), QIcon::fromTheme(":/icons/deepin/builtin/icons/dde_calendar_spinner_32px.svg"), tr("Syncing..."));
+        return;
+    }
+    //
+    if (preSyncNum == -1 && syncNum != -1) {
+        preSyncNum = -2;
+        switch (syncNum) {
+        case 0:
+            //同步成功
+            DMessageManager::instance()->sendMessage(this->window(), QIcon::fromTheme(":/icons/deepin/builtin/icons/dde_calendar_success_200px.png"), tr("Sync successful"));
+            break;
+        case 1:
+        case 2:
+        case 3:
+            //同步失败
+            DMessageManager::instance()->sendMessage(this->window(), QIcon::fromTheme(":/icons/deepin/builtin/icons/dde_calendar_fail_200px.png"), tr("Sync failed, please try later"));
+            break;
+        default:
+            break;
+        }
+    }
+}
+
+void Calendarmainwindow::slotAccountUpdate()
+{
+    AccountItem::Ptr uidAccount = gUosAccountItem;
+    if (!uidAccount.isNull()) {
+        connect(uidAccount.get(), &AccountItem::signalSyncStateChange, this, &Calendarmainwindow::slotShowSyncToast);
+    }
+}
