@@ -27,6 +27,8 @@
 
 #include <QHBoxLayout>
 #include <QMessageBox>
+#include <QDrag>
+#include <QMimeData>
 
 DGUI_USE_NAMESPACE
 CDayWindow::CDayWindow(QWidget *parent)
@@ -140,9 +142,9 @@ void CDayWindow::updateShowDate(const bool isUpdateBar)
     int w = m_scheduleView->width() - 72;
     m_scheduleView->setRange(w, 1032, getSelectDate(), getSelectDate());
     //设置时间显示格式
-    m_scheduleView->setTimeFormat(m_calendarManager->getCalendarDateDataManage()->getTimeFormat());
+    m_scheduleView->setTimeFormat((m_calendarManager->getTimeShowType()?"AP ":"") + m_calendarManager->getTimeFormat());
     //获取需要显示的时间
-    QVector<QDate> _monthDate = m_calendarManager->getCalendarDateDataManage()->getMonthDate(getSelectDate().year(), getSelectDate().month());
+    QVector<QDate> _monthDate = m_calendarManager->getMonthDate(getSelectDate().year(), getSelectDate().month());
     m_daymonthView->setShowDate(_monthDate, getSelectDate(), getCurrendDateTime().date());
     //如果为中文环境则显示农历信息
     if (getShowLunar())
@@ -156,24 +158,21 @@ void CDayWindow::updateShowDate(const bool isUpdateBar)
 void CDayWindow::updateShowSchedule()
 {
     //获取一天的日程信息
-    QMap<QDate, QVector<ScheduleDataInfo> > _weekScheduleInfo = m_calendarManager->getScheduleTask()->getScheduleInfo(getSelectDate(), getSelectDate());
+    QMap<QDate, DSchedule::List> _weekScheduleInfo = gScheduleManager->getScheduleMap(getSelectDate(), getSelectDate());
     //设置显示日程信息
     m_scheduleView->setShowScheduleInfo(_weekScheduleInfo);
     //获取界面显示定位时间位置
     setMakeTime(_weekScheduleInfo);
-    QMap<QDate, bool> _fullInfo = m_calendarManager->getScheduleTask()->getDateHasSchedule();
-    //获取当前月是否包含日程情况
-    QVector<QDate> _monthDate = m_calendarManager->getCalendarDateDataManage()->getMonthDate(getSelectDate().year(), getSelectDate().month());
-    QVector<bool> _monthFlag{};
-    for (int i = 0; i < _monthDate.size(); ++i) {
-        if (_fullInfo.contains(_monthDate.at(i))) {
-            _monthFlag.append(_fullInfo[_monthDate.at(i)]);
-        } else {
-            _monthFlag.append(false);
-        }
+
+    QSet<QDate> scheduleDate = gScheduleManager->getAllScheduleDate();
+    QVector<bool> monthFlag{};
+    QVector<QDate> monthDate = m_calendarManager->getMonthDate(getSelectDate().year(), getSelectDate().month());
+
+    for (QDate date : monthDate) {
+        monthFlag.push_back((scheduleDate.find(date) != scheduleDate.end()));
     }
     //设置日视图右侧月显示日期是否有日程
-    m_daymonthView->setHasScheduleFlag(_monthFlag);
+    m_daymonthView->setHasScheduleFlag(monthFlag);
 }
 
 /**
@@ -182,20 +181,25 @@ void CDayWindow::updateShowSchedule()
 void CDayWindow::updateShowLunar()
 {
     CaHuangLiDayInfo _huangLiInfo = getLunarInfo();
-    m_LunarLabel->setText(_huangLiInfo.mLunarMonthName + _huangLiInfo.mLunarDayName);
+    m_LunarLabel->setText(tr("Lunar") + _huangLiInfo.mLunarMonthName + _huangLiInfo.mLunarDayName);
     m_daymonthView->setHuangLiInfo(_huangLiInfo);
 }
 
+void CDayWindow::updateSearchScheduleInfo()
+{
+    m_scheduleView->slotUpdateScene();
+}
+
 /**
  * @brief CDayWindow::setSelectSearchScheduleInfo       设置选中日程
  * @param info
  */
-void CDayWindow::setSelectSearchScheduleInfo(const ScheduleDataInfo &info)
+void CDayWindow::setSelectSearchScheduleInfo(const DSchedule::Ptr &info)
 {
-    if (info.getAllDay()) {
+    if (info->allDay()) {
         setTime();
     } else {
-        m_scheduleView->setTime(info.getBeginDateTime().time());
+        m_scheduleView->setTime(info->dtStart().time());
     }
 
     m_scheduleView->setSelectSchedule(info);
@@ -240,6 +244,8 @@ void CDayWindow::initUI()
     ypa.setColor(DPalette::WindowText, QColor("#3B3B3B"));
     m_YearLabel->setPalette(ypa);
     titleLayout->addWidget(m_YearLabel);
+    m_dialogIconButton->setFocusPolicy(Qt::NoFocus);
+    titleLayout->addWidget(m_dialogIconButton);
     m_LunarLabel = new QLabel();
     titleLayout->addSpacing(15);
     m_LunarLabel->setFixedHeight(DDEDayCalendar::D_YLabelHeight);
@@ -291,7 +297,6 @@ void CDayWindow::initUI()
     m_mainLayout = new QHBoxLayout;
     m_mainLayout->setMargin(0);
     m_mainLayout->setSpacing(0);
-    m_mainLayout->setContentsMargins(10, 10, 10, 10);
     m_mainLayout->addWidget(m_leftground);
 
     this->setLayout(m_mainLayout);
@@ -309,17 +314,17 @@ void CDayWindow::initConnection()
  * @brief CDayWindow::setMakeTime       界面显示定位时间位置
  * @param info
  */
-void CDayWindow::setMakeTime(QMap<QDate, QVector<ScheduleDataInfo> > &info)
+void CDayWindow::setMakeTime(QMap<QDate, DSchedule::List> &info)
 {
     if (info.contains(getSelectDate())) {
-        QVector<ScheduleDataInfo> _scheduleVector = info[getSelectDate()];
+        DSchedule::List _scheduleVector = info[getSelectDate()];
         //设置当前第一个非全天默认时间
         QDateTime firstscheduleBeginTime(getSelectDate().addDays(1), QTime(0, 0, 0));
         //获取非全天日程
         for (int i = 0 ; i < _scheduleVector.size(); ++i) {
-            if (!_scheduleVector.at(i).getAllDay()) {
-                if (firstscheduleBeginTime > _scheduleVector.at(i).getBeginDateTime()) {
-                    firstscheduleBeginTime = _scheduleVector.at(i).getBeginDateTime();
+            if (!_scheduleVector.at(i)->allDay()) {
+                if (firstscheduleBeginTime > _scheduleVector.at(i)->dtStart()) {
+                    firstscheduleBeginTime = _scheduleVector.at(i)->dtStart();
                 }
             }
         }
@@ -370,11 +375,6 @@ void CDayWindow::resizeEvent(QResizeEvent *event)
     qreal dw = 0.4 * width();
     int dh = height() - 20;
 
-    if (m_searchFlag) {
-        m_mainLayout->setContentsMargins(10, 10, 0, 10);
-    } else {
-        m_mainLayout->setContentsMargins(10, 10, 10, 10);
-    }
     m_daymonthView->setFixedSize(qRound(dw), dh);
 }
 
