@@ -25,6 +25,7 @@
 #include "cscheduleoperation.h"
 #include "scheduledaterangeinfo.h"
 #include "calendarmanage.h"
+#include "calendarglobalenv.h"
 
 #include <DHiDPIHelper>
 #include <DPalette>
@@ -46,7 +47,7 @@ DGUI_USE_NAMESPACE
 CScheduleSearchItem::CScheduleSearchItem(QWidget *parent)
     : DLabel(parent)
     , m_rightMenu(new DMenu(this))
-    , m_timeFormat(CalendarManager::getInstance()->getCalendarDateDataManage()->getTimeFormat())
+    , m_timeFormat(CalendarManager::getInstance()->getTimeFormat())
 {
     //设置对象名称和辅助显示名称
     this->setObjectName("CScheduleDataItem");
@@ -73,11 +74,6 @@ void CScheduleSearchItem::setBackgroundColor(QColor color1)
     m_Backgroundcolor = color1;
 }
 
-void CScheduleSearchItem::setSplitLineColor(QColor color1)
-{
-    m_splitlinecolor = color1;
-}
-
 void CScheduleSearchItem::setText(QColor tColor, QFont font)
 {
     m_tTextColor = tColor;
@@ -92,7 +88,7 @@ void CScheduleSearchItem::setTimeC(QColor tColor, QFont font)
     m_timefont = font;
 }
 
-void CScheduleSearchItem::setData(ScheduleDataInfo vScheduleInfo, QDate date)
+void CScheduleSearchItem::setData(DSchedule::Ptr vScheduleInfo, QDate date)
 {
     m_ScheduleInfo = vScheduleInfo;
     m_date = date;
@@ -150,20 +146,16 @@ void CScheduleSearchItem::setDurationSize(QFont font)
 }
 void CScheduleSearchItem::slotEdit()
 {
-    emit signalViewtransparentFrame(1);
     CScheduleDlg dlg(0, this);
     dlg.setData(m_ScheduleInfo);
     dlg.exec();
-    emit signalViewtransparentFrame(0);
 }
 
 void CScheduleSearchItem::slotDelete()
 {
-    emit signalViewtransparentFrame(1);
     //删除日程
-    CScheduleOperation _scheduleOperation(this);
+    CScheduleOperation _scheduleOperation(m_ScheduleInfo->scheduleTypeID(), this);
     bool _isDelete = _scheduleOperation.deleteSchedule(m_ScheduleInfo);
-    emit signalViewtransparentFrame(0);
     //删除日程后，将焦点设置给父类
     if (_isDelete) {
         parentWidget()->setFocus(Qt::TabFocusReason);
@@ -190,7 +182,7 @@ void CScheduleSearchItem::slotSchotCutClicked()
     //选中该item时才可以使用快捷键
     if (m_tabFocus) {
         //节日日程不能使用
-        if (m_ScheduleInfo.getType() == DDECalendar::FestivalTypeID)
+        if (CScheduleOperation::isFestival(m_ScheduleInfo))
             return;
         m_rightMenu->clear();
         m_rightMenu->addAction(m_editAction);
@@ -206,8 +198,8 @@ void CScheduleSearchItem::slotSchotCutClicked()
 void CScheduleSearchItem::paintEvent(QPaintEvent *e)
 {
     Q_UNUSED(e);
-    int labelwidth = width() - 2;
-    int labelheight = height() - 2;
+    int labelRightX = width() - 2; //绘制区域x方向右边界坐标点
+    int labelBottomY = height();    //绘制区域y方向下边界坐标点
     QPainter painter(this);
     QColor bColor = m_Backgroundcolor;
     QColor textcolor = m_tTextColor;
@@ -233,50 +225,44 @@ void CScheduleSearchItem::paintEvent(QPaintEvent *e)
     painter.save();
     painter.setRenderHint(QPainter::Antialiasing); // 反锯齿;
     painter.setBrush(QBrush(bColor));
-    if (m_tabFocus) {
-        //设置焦点绘制的pen
-        QPen pen;
-        pen.setColor(CScheduleDataManage::getScheduleDataManage()->getSystemActiveColor());
-        pen.setWidth(2);
-        painter.setPen(pen);
-    } else
-        painter.setPen(Qt::NoPen);
+    painter.setPen(Qt::NoPen);
+
     QPainterPath painterPath;
-    painterPath.moveTo(m_radius, m_borderframew);
+    painterPath.moveTo(m_radius, m_borderframewY);
 
     if (m_roundtype == 1 || m_roundtype == 3) {
-        painterPath.arcTo(QRect(m_borderframew, m_borderframew, m_radius * 2, m_radius * 2), 90, 90);
+        painterPath.arcTo(QRect(m_borderframewX, m_borderframewY, m_radius * 2, m_radius * 2), 90, 90);
     } else {
-        painterPath.lineTo(m_borderframew, m_borderframew);
-        painterPath.lineTo(m_borderframew, m_radius);
+        painterPath.lineTo(m_borderframewX, m_borderframewY);
+        painterPath.lineTo(m_borderframewX, m_radius);
     }
-    painterPath.lineTo(1, labelheight - m_radius);
+    painterPath.lineTo(m_borderframewX, labelBottomY - m_radius);
 
     if (m_roundtype == 1 || m_roundtype == 2) {
-        painterPath.arcTo(QRect(m_borderframew, labelheight - m_radius * 2, m_radius * 2, m_radius * 2), 180, 90);
+        painterPath.arcTo(QRect(m_borderframewX, labelBottomY - m_radius * 2, m_radius * 2, m_radius * 2), 180, 90);
     } else {
-        painterPath.lineTo(m_borderframew, labelheight);
-        painterPath.lineTo(m_radius, labelheight);
+        painterPath.lineTo(m_borderframewX, labelBottomY);
+        painterPath.lineTo(m_radius, labelBottomY);
     }
-    painterPath.lineTo(labelwidth - m_radius, labelheight);
+    painterPath.lineTo(labelRightX - m_radius, labelBottomY);
 
     if (m_roundtype == 1 || m_roundtype == 2) {
-        painterPath.arcTo(QRect(labelwidth - m_radius * 2, labelheight - m_radius * 2, m_radius * 2, m_radius * 2), 270, 90);
+        painterPath.arcTo(QRect(labelRightX - m_radius * 2, labelBottomY - m_radius * 2, m_radius * 2, m_radius * 2), 270, 90);
     } else {
-        painterPath.lineTo(labelwidth, labelheight);
-        painterPath.lineTo(labelwidth, labelheight - m_radius);
+        painterPath.lineTo(labelRightX, labelBottomY);
+        painterPath.lineTo(labelRightX, labelBottomY - m_radius);
     }
-    painterPath.lineTo(labelwidth, m_radius);
+    painterPath.lineTo(labelRightX, m_radius);
 
     if (m_roundtype == 1 || m_roundtype == 3) {
-        painterPath.arcTo(QRect(labelwidth - m_radius * 2, m_borderframew, m_radius * 2, m_radius * 2), 0, 90);
+        painterPath.arcTo(QRect(labelRightX - m_radius * 2, m_borderframewY, m_radius * 2, m_radius * 2), 0, 90);
 
     } else {
-        painterPath.lineTo(labelwidth, m_borderframew);
-        painterPath.lineTo(labelwidth - m_radius, m_borderframew);
+        painterPath.lineTo(labelRightX, m_borderframewY);
+        painterPath.lineTo(labelRightX - m_radius, m_borderframewY);
     }
 
-    painterPath.lineTo(m_radius, m_borderframew);
+    painterPath.lineTo(m_radius, m_borderframewY);
     painterPath.closeSubpath();
     painter.drawPath(painterPath);
     painter.restore();
@@ -286,22 +272,26 @@ void CScheduleSearchItem::paintEvent(QPaintEvent *e)
 
     QString datestr;
 
-    datestr = m_ScheduleInfo.getBeginDateTime().toString(m_timeFormat)
-              + "-" + m_ScheduleInfo.getEndDateTime().toString(m_timeFormat);
+    datestr = m_ScheduleInfo->dtStart().toString(m_timeFormat)
+              + "-" + m_ScheduleInfo->dtEnd().toString(m_timeFormat);
 
     int flag = Qt::AlignLeft | Qt::AlignVCenter;
 
-    if (m_ScheduleInfo.getAllDay()) {
+    if (m_ScheduleInfo->allDay()) {
         datestr = tr("All Day");
     }
-    painter.drawText(QRect(12, 8, m_durationSize, labelheight - 16), flag, datestr);
+    painter.drawText(QRect(12, 8, m_durationSize, labelBottomY - 16), flag, datestr);
 
     painter.save();
-    bColor = m_splitlinecolor;
+    DScheduleType::Ptr type =  gScheduleManager->getScheduleTypeByScheduleId(m_ScheduleInfo->scheduleTypeID());
+    if (nullptr != type) {
+        bColor = type->typeColor().colorCode();
+    }
     QPen pen(bColor);
     pen.setWidth(2);
     painter.setPen(pen);
-    painter.drawLine(m_durationSize + 17, 0, m_durationSize + 17, labelheight);
+    //由于绘制的矩形大小的改变，所以需要调整起始和截止y坐标
+    painter.drawLine(m_durationSize + 17, m_borderframewY, m_durationSize + 17, labelBottomY);
     painter.restore();
 
     painter.setFont(m_tFont);
@@ -309,8 +299,8 @@ void CScheduleSearchItem::paintEvent(QPaintEvent *e)
     QString ellipsis = "...";
     QFontMetrics fm = painter.fontMetrics();
     //整个label宽度-文字起始位置
-    int tilenameW = labelwidth - (m_durationSize + 26);
-    QString tSTitleName = m_ScheduleInfo.getTitleName();
+    int tilenameW = labelRightX - m_borderframewX - (m_durationSize + 26);
+    QString tSTitleName = m_ScheduleInfo->summary();
     tSTitleName.replace("\n", "");
     QString str = tSTitleName;
     QString tStr;
@@ -329,15 +319,28 @@ void CScheduleSearchItem::paintEvent(QPaintEvent *e)
     if (tStr != str) {
         tStr = tStr + "...";
     }
+    this->setToolTip(str);
+    painter.drawText(QRect(m_durationSize + 17 + 9, 6, tilenameW, labelBottomY), Qt::AlignLeft, tStr);
+
+    //存在焦点时绘制边框
+    if (m_tabFocus) {
+        painter.setPen(Qt::NoPen);
+        // 设置画刷颜色
+        painter.setBrush(CScheduleDataManage::getScheduleDataManage()->getSystemActiveColor());
+        QPainterPath path;
+        int w = 2; //边框宽度
+        path.addRect(m_borderframewX, m_borderframewY, labelRightX - m_borderframewX, labelBottomY - m_borderframewY);
+        path.addRect(m_borderframewX + w, m_borderframewY + w, labelRightX - 2 * w - m_borderframewX, labelBottomY - 2 * w - m_borderframewY);
+        painter.drawPath(path);
+    }
 
-    painter.drawText(QRect(m_durationSize + 17 + 9, 6, tilenameW, labelheight), Qt::AlignLeft, tStr);
     painter.end();
 }
 void CScheduleSearchItem::contextMenuEvent(QContextMenuEvent *event)
 {
     Q_UNUSED(event);
-
-    if (m_ScheduleInfo.getType() == DDECalendar::FestivalTypeID)
+    //判断是否为节假日日程
+    if (CScheduleOperation::isFestival(m_ScheduleInfo))
         return;
     //在有些环境中弹出右击菜单不会触发leaveEvent，主动更新leave对应的事件处理
     m_mouseStatus = M_NONE;
@@ -345,16 +348,18 @@ void CScheduleSearchItem::contextMenuEvent(QContextMenuEvent *event)
     m_rightMenu->clear();
     m_rightMenu->addAction(m_editAction);
     m_rightMenu->addAction(m_deleteAction);
+    //不可修改的日程删除按钮无效
+    m_deleteAction->setEnabled(!CScheduleOperation::scheduleIsInvariant(m_ScheduleInfo));
     m_rightMenu->exec(QCursor::pos());
+    //恢复按钮状态
+    m_deleteAction->setEnabled(true);
 }
 
 void CScheduleSearchItem::mouseDoubleClickEvent(QMouseEvent *event)
 {
     Q_UNUSED(event);
-    emit signalViewtransparentFrame(1);
     CMyScheduleView dlg(m_ScheduleInfo, this);
     dlg.exec();
-    emit signalViewtransparentFrame(0);
 }
 
 void CScheduleSearchItem::mousePressEvent(QMouseEvent *event)
@@ -362,6 +367,10 @@ void CScheduleSearchItem::mousePressEvent(QMouseEvent *event)
     //鼠标点击取消焦点显示
     m_tabFocus = false;
     if (event->button() == Qt::LeftButton) {
+        //注册为鼠标操作
+        if (!CalendarGlobalEnv::getGlobalEnv()->registerKey("SearchItemEvent", "MousePress")) {
+            CalendarGlobalEnv::getGlobalEnv()->reviseValue("SearchItemEvent", "MousePress");
+        }
         emit signalSelectSchedule(m_ScheduleInfo);
     }
     DLabel::mousePressEvent(event);
@@ -407,6 +416,10 @@ bool CScheduleSearchItem::eventFilter(QObject *o, QEvent *e)
 void CScheduleSearchItem::focusInEvent(QFocusEvent *e)
 {
     if (e->reason() == Qt::TabFocusReason) {
+        //注册为键盘操作
+        if (!CalendarGlobalEnv::getGlobalEnv()->registerKey("SearchItemEvent", "Keyboard")) {
+            CalendarGlobalEnv::getGlobalEnv()->reviseValue("SearchItemEvent", "Keyboard");
+        }
         emit signalSelectSchedule(m_ScheduleInfo);
         emit signalSelectCurrentItem(this, false);
         m_tabFocus = true;
@@ -445,7 +458,6 @@ CScheduleSearchView::CScheduleSearchView(QWidget *parent)
     : DWidget(parent)
 {
     QVBoxLayout *layout = new QVBoxLayout;
-    layout->setMargin(0);
     layout->setSpacing(0);
     m_gradientItemList = new CScheduleListWidget(parent);
     m_gradientItemList->setAlternatingRowColors(true);
@@ -460,8 +472,7 @@ CScheduleSearchView::CScheduleSearchView(QWidget *parent)
     m_labellist.clear();
 
     connect(m_gradientItemList, &CScheduleListWidget::signalListWidgetClicked, this, &CScheduleSearchView::slotListWidgetClicked);
-    CScheduleTask *_scheduleTask = CalendarManager::getInstance()->getScheduleTask();
-    connect(_scheduleTask, &CScheduleTask::jobsUpdate, this, &CScheduleSearchView::updateSearch);
+    connect(gScheduleManager, &ScheduleManager::signalSearchScheduleUpdate, this, &CScheduleSearchView::slotScearedScheduleUpdate);
 }
 
 CScheduleSearchView::~CScheduleSearchView()
@@ -516,7 +527,7 @@ void CScheduleSearchView::clearSearch()
     m_labellist.clear();
     m_gradientItemList->clear();
     //清空搜索数据
-    CalendarManager::getInstance()->getScheduleTask()->clearSearchScheduleInfo();
+    gScheduleManager->clearSearchSchedule();
 }
 
 void CScheduleSearchView::setMaxWidth(const int w)
@@ -547,7 +558,7 @@ void CScheduleSearchView::deleteSchedule()
 {
     currentDItemIndex = m_scheduleSearchItem.indexOf(m_selectItem);
     //如果存在该item且为节日日程不可操作
-    if (currentDItemIndex >= 0 && m_selectItem->getData().getType() != DDECalendar::FestivalTypeID) {
+    if (currentDItemIndex >= 0 && !CScheduleOperation::isFestival(m_selectItem->getData())) {
         m_selectItem->slotDelete();
     }
 }
@@ -573,17 +584,17 @@ void CScheduleSearchView::updateDateShow()
     //找最近日程
     QDate tCurrentData = QDate::currentDate();
     //搜索日程过滤排序
-    QMap<QDate, QVector<ScheduleDataInfo> > m_showData;
+    QMap<QDate, DSchedule::List> m_showData;
     qint64 offset = 1000;
     QDate topdate = tCurrentData;
-    QMap<QDate, QVector<ScheduleDataInfo> >::const_iterator  _iterator = m_vlistData.constBegin();
-    QVector<ScheduleDataInfo> _showInfo{};
+    QMap<QDate, DSchedule::List>::const_iterator _iterator = m_vlistData.constBegin();
+    DSchedule::List _showInfo {};
     for (; _iterator != m_vlistData.constEnd(); ++_iterator) {
         qint64 d = qAbs(_iterator.key().daysTo(tCurrentData));
         _showInfo.clear();
         for (int i = 0 ; i < _iterator.value().size(); ++i) {
             //如果开始时间日期为显示日期则显示,跨天日程只显示一个
-            if (_iterator.value().at(i).getBeginDateTime().date() == _iterator.key() || _iterator == m_vlistData.constBegin()) {
+            if (_iterator.value().at(i)->dtStart().date() == _iterator.key() || _iterator == m_vlistData.constBegin()) {
                 _showInfo.append(_iterator.value().at(i));
             }
         }
@@ -599,7 +610,7 @@ void CScheduleSearchView::updateDateShow()
         }
     }
     tCurrentData = topdate;
-    QMap<QDate, QVector<ScheduleDataInfo> >::const_iterator  _showIterator = m_showData.constBegin();
+    QMap<QDate, DSchedule::List>::const_iterator _showIterator = m_showData.constBegin();
     for (; _showIterator != m_showData.constEnd(); ++_showIterator) {
         //创建显示日期项
         QListWidgetItem *dateItem = createItemWidget(_showIterator.key());
@@ -623,6 +634,7 @@ void CScheduleSearchView::updateDateShow()
         hasScheduleShow = false;
         QListWidgetItem *listItem = new QListWidgetItem(m_gradientItemList);
         DLabel *gwi = new DLabel();
+        gwi->setWordWrap(true);
         QFont font;
         font.setPixelSize(DDECalendar::FontSizeTwenty);
         gwi->setAlignment(Qt::AlignCenter);
@@ -668,34 +680,29 @@ void CScheduleSearchView::updateDateShow()
     }
 }
 
-void CScheduleSearchView::createItemWidget(ScheduleDataInfo info, QDate date, int rtype)
+void CScheduleSearchView::createItemWidget(DSchedule::Ptr info, QDate date, int rtype)
 {
-    ScheduleDataInfo &gd = info;
-    CSchedulesColor gdColor = CScheduleDataManage::getScheduleDataManage()->getScheduleColorByType(gd.getType());
+    DSchedule::Ptr &gd = info;
 
     CScheduleSearchItem *gwi = new CScheduleSearchItem(this);
     QFont font;
     font.setPixelSize(DDECalendar::FontSizeFourteen);
     font.setWeight(QFont::Normal);
     gwi->setBackgroundColor(m_bBackgroundcolor);
-    QColor sColor = gdColor.Purecolor;
-    sColor.setAlphaF(1.0);
-    gwi->setSplitLineColor(gdColor.splitColor);
     gwi->setText(m_btTextColor, font);
     font.setPixelSize(DDECalendar::FontSizeTwelve);
 
     gwi->setTimeC(m_btimecolor, font);
-    gwi->setFixedSize(m_maxWidth - 25, 35);
+    gwi->setFixedSize(m_maxWidth - 15, 35);
     gwi->setData(gd, date);
     gwi->setRoundtype(rtype);
     //将搜索到的日程添加到容器
     m_scheduleSearchItem.append(gwi);
     connect(gwi, &CScheduleSearchItem::signalSelectSchedule, this, &CScheduleSearchView::slotSelectSchedule);
-    connect(gwi, &CScheduleSearchItem::signalViewtransparentFrame, this, &CScheduleSearchView::signalViewtransparentFrame);
     connect(gwi, &CScheduleSearchItem::signalSelectCurrentItem, this, &CScheduleSearchView::slotSelectCurrentItem);
 
     QListWidgetItem *listItem = new QListWidgetItem;
-    listItem->setSizeHint(QSize(m_maxWidth - 25, 36)); //每次改变Item的高度
+    listItem->setSizeHint(QSize(m_maxWidth - 15, 36)); //每次改变Item的高度
     listItem->setFlags(Qt::ItemIsTristate);
     m_gradientItemList->addItem(listItem);
     m_gradientItemList->setItemWidget(listItem, gwi);
@@ -714,14 +721,14 @@ QListWidgetItem *CScheduleSearchView::createItemWidget(QDate date)
     if (date == QDate::currentDate()) {
         gwi->setText(CScheduleDataManage::getScheduleDataManage()->getSystemActiveColor(), font);
     }
-    gwi->setFixedSize(m_maxWidth - 25, 35);
+    gwi->setFixedSize(m_maxWidth - 15, 35);
     gwi->setDate(date);
     connect(gwi,
             &CScheduleSearchDateItem::signalLabelScheduleHide,
             this,
             &CScheduleSearchView::signalScheduleHide);
     QListWidgetItem *listItem = new QListWidgetItem;
-    listItem->setSizeHint(QSize(m_maxWidth - 25, 36)); //每次改变Item的高度
+    listItem->setSizeHint(QSize(m_maxWidth - 15, 36)); //每次改变Item的高度
     listItem->setFlags(Qt::ItemIsTristate);
     m_gradientItemList->addItem(listItem);
     m_gradientItemList->setItemWidget(listItem, gwi);
@@ -746,11 +753,16 @@ void CScheduleSearchView::slotsetSearch(QString str)
     }
     QDateTime eDate = date.addMonths(6);
     //查询搜索
-    m_vlistData = CalendarManager::getInstance()->getScheduleTask()->getSearchScheduleInfo(str, bDate, eDate);
+    gScheduleManager->searchSchedule(str, bDate, eDate);
+}
+
+void CScheduleSearchView::slotScearedScheduleUpdate()
+{
+    m_vlistData = gScheduleManager->getAllSearchedScheduleMap();
     updateDateShow();
 }
 
-void CScheduleSearchView::slotSelectSchedule(const ScheduleDataInfo &scheduleInfo)
+void CScheduleSearchView::slotSelectSchedule(const DSchedule::Ptr &scheduleInfo)
 {
     emit signalSelectSchedule(scheduleInfo);
 }
@@ -810,8 +822,8 @@ void CScheduleSearchView::resizeEvent(QResizeEvent *event)
     }
     if (m_gradientItemList->count() == 1) {
         QListWidgetItem *item11 = m_gradientItemList->item(0);
-        item11->setSizeHint(QSize(m_maxWidth, qRound(height() * 0.7978))); //每次改变Item的高度
-        m_labellist.at(0)->setFixedSize(m_maxWidth, qRound(height() * 0.7978));
+        item11->setSizeHint(QSize(m_maxWidth - 20, qRound(height() * 0.7978))); //每次改变Item的高度
+        m_labellist.at(0)->setFixedSize(m_maxWidth - 20, qRound(height() * 0.7978));
         m_labellist.at(0)->update();
     }
     if (m_gradientItemList->count() > 1) {
@@ -925,6 +937,11 @@ CScheduleListWidget::CScheduleListWidget(QWidget *parent)
     grabGesture(Qt::TapGesture);
     grabGesture(Qt::TapAndHoldGesture);
     grabGesture(Qt::PanGesture);
+
+    //日程类型发生改变，刷新界面
+    connect(gAccountManager, &AccountManager::signalScheduleTypeUpdate, [&]() {
+        this->viewport()->update();
+    });
 }
 
 CScheduleListWidget::~CScheduleListWidget()
@@ -956,7 +973,9 @@ void CScheduleListWidget::paintEvent(QPaintEvent *e)
     painter.setPen(Qt::NoPen);
     painter.setBrush(_outBorderColor);
 
-    const qreal _outWidth = 10;
+//    const qreal _outWidth = 10;
+    //不需要outwidth
+    const qreal _outWidth = 0;
     const qreal _rectX = this->width() - _outWidth;
     QPainterPath _showPath;
     _showPath.moveTo(_rectX - _radios, 0);
