@@ -113,13 +113,6 @@ void CYearWindow::resizeEvent(QResizeEvent *event)
 {
     Q_UNUSED(event);
     m_topWidget->setGeometry(0, 0, this->width(), DDEMonthCalendar::M_YTopHeight);
-    if (m_searchFlag) {
-        m_tMainLayout->setContentsMargins(10, 0, 2, 0);
-        m_topWidget->setContentsMargins(10, 0, 2, 0);
-    } else {
-        m_tMainLayout->setContentsMargins(10, 0, 10, 0);
-        m_topWidget->setContentsMargins(10, 0, 10, 0);
-    }
 }
 
 void CYearWindow::mouseMoveEvent(QMouseEvent *event)
@@ -331,13 +324,13 @@ void CYearWindow::initUI()
     QHBoxLayout *yeartitleLayout = new QHBoxLayout;
     yeartitleLayout->setMargin(0);
     yeartitleLayout->setSpacing(0);
-    yeartitleLayout->setContentsMargins(11, 12, 8, 10);
+    yeartitleLayout->addSpacing(10);
     yeartitleLayout->addWidget(m_yearLabel);
+    yeartitleLayout->addWidget(m_dialogIconButton);
 
     QHBoxLayout *yeartitleLayout1 = new QHBoxLayout;
     yeartitleLayout1->setMargin(0);
     yeartitleLayout1->setSpacing(0);
-    yeartitleLayout1->setContentsMargins(4, 9, 0, 7);
     yeartitleLayout1->addWidget(m_yearLunarLabel);
     yeartitleLayout1->addSpacing(390);
     yeartitleLayout1->addStretch();
@@ -361,6 +354,7 @@ void CYearWindow::initUI()
     m_todayFrame->setLayout(todaylayout);
     yeartitleLayout1->addSpacing(10);
     yeartitleLayout1->addWidget(m_todayFrame);
+    yeartitleLayout->addSpacing(6);
     yeartitleLayout->addLayout(yeartitleLayout1);
 
     m_firstYearWidget = new YearFrame();
@@ -387,7 +381,7 @@ void CYearWindow::initUI()
     m_tMainLayout = new QVBoxLayout;
     m_tMainLayout->setMargin(0);
     m_tMainLayout->setSpacing(0);
-    m_tMainLayout->setContentsMargins(10, 0, 10, 0);
+    m_tMainLayout->setContentsMargins(0, 0, 0, 0);
     m_tMainLayout->addLayout(hhLayout);
     this->setLayout(m_tMainLayout);
 
@@ -408,7 +402,6 @@ void CYearWindow::initConnection()
     connect(m_firstYearWidget, &YearFrame::signalMousePress, this, &CYearWindow::slotMousePress);
     connect(m_secondYearWidget, &YearFrame::signalMousePress, this, &CYearWindow::slotMousePress);
     connect(m_scheduleView, &CYearScheduleOutView::signalsViewSelectDate, this, &CYearWindow::slotMousePress);
-    connect(m_scheduleView, &CYearScheduleOutView::signalViewtransparentFrame, this, &CYearWindow::signalViewtransparentFrame);
 }
 
 /**
@@ -488,9 +481,8 @@ void CYearWindow::setSearchWFlag(bool flag)
 void CYearWindow::updateShowDate(const bool isUpdateBar)
 {
     Q_UNUSED(isUpdateBar);
-    QMap<int, QVector<QDate> > _yearShowData = m_calendarManager->getCalendarDateDataManage()->getYearDate();
-    m_scheduleView->setTimeFormat(m_calendarManager->getCalendarDateDataManage()->getTimeFormat());
-    m_yearWidget->setShowDate(getSelectDate(), _yearShowData);
+    m_scheduleView->setTimeFormat((m_calendarManager->getTimeShowType()?"AP ":"") + m_calendarManager->getTimeFormat());
+    m_yearWidget->setShowDate(getSelectDate());
 }
 
 /**
@@ -499,8 +491,8 @@ void CYearWindow::updateShowDate(const bool isUpdateBar)
 void CYearWindow::updateShowSchedule()
 {
     //获取显示日期中是否包含日程信息标志
-    QMap<QDate, bool> _fullInfo = m_calendarManager->getScheduleTask()->getDateHasSchedule();
-    m_yearWidget->setDateHasScheduleSign(_fullInfo);
+    m_yearWidget->setDateHasScheduleSign(ScheduleManager::getInstace()->getAllScheduleDate());
+
 }
 
 /**
@@ -508,6 +500,7 @@ void CYearWindow::updateShowSchedule()
  */
 void CYearWindow::updateShowLunar()
 {
+    //获取农历信息
     getLunarInfo();
     m_yearWidget->setLunarYearDate(m_lunarYear);
     //如果正在切换则退出
@@ -522,15 +515,14 @@ void CYearWindow::updateShowLunar()
 void CYearWindow::updateSearchScheduleInfo()
 {
     //获取搜索日程信息
-    QMap<QDate, QVector<ScheduleDataInfo> > _searchSchedule = m_calendarManager->getScheduleTask()->getSearchScheduleInfo();
-    m_yearWidget->setSearchSchedule(_searchSchedule);
+    m_yearWidget->setSearchSchedule(gScheduleManager->getAllSearchedScheduleDate());
 }
 
 /**
  * @brief CYearWindow::setSelectSearchScheduleInfo      设置选中搜索日程
  * @param info
  */
-void CYearWindow::setSelectSearchScheduleInfo(const ScheduleDataInfo &info)
+void CYearWindow::setSelectSearchScheduleInfo(const DSchedule::Ptr &info)
 {
     Q_UNUSED(info);
 }
@@ -548,7 +540,11 @@ void CYearWindow::slotSetScheduleHide()
  */
 void CYearWindow::slotprev()
 {
-    switchYear(-1);
+    QDate minYear = getSelectDate();
+    if (minYear.year() > 1900)
+    {
+        switchYear(-1);
+    }
 }
 
 /**
@@ -556,7 +552,11 @@ void CYearWindow::slotprev()
  */
 void CYearWindow::slotnext()
 {
-    switchYear(1);
+    QDate maxYear = getSelectDate();
+    if (maxYear.year() < 2100)
+    {
+        switchYear(1);
+    }
 }
 
 /**
@@ -586,28 +586,26 @@ void CYearWindow::switchYear(const int offsetYear)
     if (m_StackedWidget->IsRunning())
         return;
     _selectData = _selectData.addYears(offsetYear);
-    //设置选择时间，如果成功则切换
-    if (setSelectDate(_selectData, true)) {
-        int index = m_StackedWidget->currentIndex();
-        //当前选中的monthview的index
-        int currentYearViewIndex = qobject_cast<YearFrame *>(m_StackedWidget->widget(index))->getViewFocusIndex();
-        index = qAbs(index + offsetYear) % 2;
-        m_yearWidget = qobject_cast<YearFrame *>(m_StackedWidget->widget(index));
-        //设置年视图翻页后选中的monthview
-        m_yearWidget->setViewFocus(currentYearViewIndex);
-        //获取一年的显示时间
-        QMap<int, QVector<QDate> > _yearShowData = m_calendarManager->getCalendarDateDataManage()->getYearDate();
-        //设置显示时间
-        m_yearWidget->setShowDate(getSelectDate(), _yearShowData);
-        updateData();
-        if (offsetYear > 0) {
-            //下一年
-            m_StackedWidget->setNext();
-        } else {
-            //上一年
-            m_StackedWidget->setPre();
-        }
+    //获取当前显示控件的位置
+    int index = m_StackedWidget->currentIndex();
+    //当前选中的monthview的index
+    int currentYearViewIndex = qobject_cast<YearFrame *>(m_StackedWidget->widget(index))->getViewFocusIndex();
+    index = qAbs(index + offsetYear) % 2;
+    m_yearWidget = qobject_cast<YearFrame *>(m_StackedWidget->widget(index));
+    //设置年视图翻页后选中的monthview
+    m_yearWidget->setViewFocus(currentYearViewIndex);
+    //设置显示时间
+    m_yearWidget->setShowDate(_selectData);
+    updateData();
+    if (offsetYear > 0) {
+        //下一年
+        m_StackedWidget->setNext();
+    } else {
+        //上一年
+        m_StackedWidget->setPre();
     }
+    //切换试图开始后再进行时间切换
+    setSelectDate(_selectData);
 }
 
 /**
@@ -634,6 +632,7 @@ void CYearWindow::setYearData()
     if (getShowLunar()) {
         m_yearLabel->setText(QString::number(getSelectDate().year()) + tr("Y"));
         //获取农历信息
+        //获取农历信息
         getLunarInfo();
         //显示农历信息
         setLunarShow();
@@ -653,17 +652,15 @@ void CYearWindow::slotMousePress(const QDate &selectDate, const int pressType)
     if (!selectDate.isValid())
         return;
     //设置选择时间
-    setSelectDate(selectDate);
+    setSelectDate(selectDate, this);
     setYearData();
     switch (pressType) {
     case 0: {
         // 0:单击
-        QVector<ScheduleDataInfo> _scheduleInfo {};
+        DSchedule::List _scheduleInfo {};
         //获取选择日期的日程信息
-        QMap<QDate, QVector<ScheduleDataInfo> > showInfo = m_calendarManager->getScheduleTask()->getScheduleInfo(selectDate, selectDate);
-        if (showInfo.begin() != showInfo.end()) {
-            _scheduleInfo = showInfo.begin().value();
-        }
+        _scheduleInfo = gScheduleManager->getScheduleByDay(selectDate);
+
         m_scheduleView->setCurrentDate(selectDate);
         m_scheduleView->setData(_scheduleInfo);
         //使用设置的显示坐标
@@ -678,6 +675,7 @@ void CYearWindow::slotMousePress(const QDate &selectDate, const int pressType)
             m_scheduleView->setDirection(DArrowRectangle::ArrowRight);
             m_scheduleView->show(pos22.x() - 10, pos22.y());
         }
+        update();
         break;
     }
     case 1: {
@@ -722,7 +720,6 @@ YearFrame::YearFrame(DWidget *parent)
     QGridLayout *gridLayout = new QGridLayout;
     gridLayout->setMargin(0);
     gridLayout->setSpacing(8);
-    gridLayout->setContentsMargins(0, 0, 0, 0);
 
     for (int i = 0; i < 3; i++) {
         for (int j = 0; j < 4; j++) {
@@ -779,11 +776,9 @@ YearFrame::YearFrame(DWidget *parent)
     QVBoxLayout *hhLayout = new QVBoxLayout;
     hhLayout->setMargin(0);
     hhLayout->setSpacing(0);
-    hhLayout->setContentsMargins(0, 0, 0, 0);
     hhLayout->addWidget(m_topWidget);
     hhLayout->addLayout(gridLayout);
     this->setLayout(hhLayout);
-    setContentsMargins(0, 0, 0, 10);
 }
 
 YearFrame::~YearFrame()
@@ -796,16 +791,14 @@ YearFrame::~YearFrame()
  * @param selectDate                    选择的时间
  * @param showDate                      需要显示一年的时间
  */
-void YearFrame::setShowDate(const QDate &selectDate, const QMap<int, QVector<QDate> > &showDate)
+void YearFrame::setShowDate(const QDate &selectDate)
 {
-    //判断是否显示12个月
-    Q_ASSERT(showDate.size() == 12);
-    m_selectDate = selectDate;
-    QDate _showMonth(m_selectDate.year(), 1, 1);
+    QDate _showMonth(selectDate.year(), 1, 1);
     for (int i = 0; i < DDEYearCalendar::FrameSizeOfEveryYear; i++) {
         QDate _setShowMonth = _showMonth.addMonths(i);
-        m_monthViewList.at(i)->setShowDate(_setShowMonth, showDate[i + 1]);
+        m_monthViewList.at(i)->setShowMonthDate(_setShowMonth);
     }
+    m_selectDate = selectDate;
     //更新显示界面
     update();
     //设置年份显示
@@ -825,27 +818,25 @@ void YearFrame::setLunarYearDate(const QString &lunar)
  * @brief YearFrame::setDateHasScheduleSign     设置日期是否存在日程
  * @param hasSchedule
  */
-void YearFrame::setDateHasScheduleSign(const QMap<QDate, bool> &hasSchedule)
+void YearFrame::setDateHasScheduleSign(const QSet<QDate> &hasSchedule)
 {
     QDate _startDate;
     QDate _stopDate;
     QDate _getDate;
     qint64 _offset = 0;
-    QVector<bool> _hasScheduleVector{};
+    QSet<QDate> _hasScheduleSet{};
     for (int i = 0; i < m_monthViewList.size(); ++i) {
         //如果时间有效
         if (m_monthViewList.at(i)->getStartAndStopDate(_startDate, _stopDate)) {
             _offset = _startDate.daysTo(_stopDate) + 1;
-            _hasScheduleVector.clear();
+            _hasScheduleSet.clear();
             for (int j = 0 ; j < _offset; ++j) {
                 _getDate = _startDate.addDays(j);
                 if (hasSchedule.contains(_getDate)) {
-                    _hasScheduleVector.append(hasSchedule[_getDate]);
-                } else {
-                    _hasScheduleVector.append(false);
+                    _hasScheduleSet.insert(_getDate);
                 }
             }
-            m_monthViewList.at(i)->setHasScheduleFlag(_hasScheduleVector);
+            m_monthViewList.at(i)->setHasScheduleSet(_hasScheduleSet);
         }
     }
 }
@@ -896,30 +887,29 @@ void YearFrame::setTheMe(int type)
  * @brief YearFrame::setSearchSchedule      设置搜索日程
  * @param searchInfo
  */
-void YearFrame::setSearchSchedule(const QMap<QDate, QVector<ScheduleDataInfo> > &searchInfo)
+void YearFrame::setSearchSchedule(const QSet<QDate> &hasSchedule)
 {
     QDate _startDate;
     QDate _stopDate;
     QDate _getDate;
     qint64 _offset = 0;
-    QVector<bool> _hasSearchScheduleVector{};
+    QSet<QDate> _hasSearchScheduleSet{};
     for (int i = 0; i < m_monthViewList.size(); ++i) {
         //如果时间有效
         if (m_monthViewList.at(i)->getStartAndStopDate(_startDate, _stopDate)) {
             _offset = _startDate.daysTo(_stopDate) + 1;
-            _hasSearchScheduleVector.clear();
+            _hasSearchScheduleSet.clear();
             for (int j = 0 ; j < _offset; ++j) {
                 _getDate = _startDate.addDays(j);
-                if (searchInfo.contains(_getDate) && searchInfo[_getDate].size() > 0) {
-                    _hasSearchScheduleVector.append(true);
-                } else {
-                    _hasSearchScheduleVector.append(false);
+                if (hasSchedule.contains(_getDate)) {
+                    _hasSearchScheduleSet.insert(_getDate);
                 }
             }
-            m_monthViewList.at(i)->setHasSearchScheduleFlag(_hasSearchScheduleVector);
+            m_monthViewList.at(i)->setHasSearchScheduleSet(_hasSearchScheduleSet);
         }
     }
 
+
 }
 
 /**
