@@ -21,28 +21,28 @@
 #ifndef TEST_LUNARCALENDARWIDGET_H
 #define TEST_LUNARCALENDARWIDGET_H
 
-#include "lunarcalendarwidget.h"
-#include <QObject>
-#include <QTest>
-#include <gtest/gtest.h>
+//#include "lunarcalendarwidget.h"
+//#include <QObject>
+//#include <QTest>
+//#include <gtest/gtest.h>
 
-class test_lunarcalendarwidget: public::testing::Test
-{
-public:
-    test_lunarcalendarwidget();
+//class test_lunarcalendarwidget: public::testing::Test
+//{
+//public:
+//    test_lunarcalendarwidget();
 
-    virtual void SetUp()
-    {
-        mWidget = new LunarCalendarWidget();
-    }
+//    virtual void SetUp()
+//    {
+//        mWidget = new LunarCalendarWidget();
+//    }
 
-    virtual void TearDown()
-    {
-        delete mWidget;
-        mWidget = nullptr;
-    }
-protected:
-    LunarCalendarWidget *mWidget = nullptr;
-};
+//    virtual void TearDown()
+//    {
+//        delete mWidget;
+//        mWidget = nullptr;
+//    }
+//protected:
+//    LunarCalendarWidget *mWidget = nullptr;
+//};
 
 #endif // TEST_LUNARCALENDARWIDGET_H
